@@ -1,11 +1,13 @@
 from abc import ABC, abstractmethod
-from typing import Callable, Any
+from typing import Callable, Any, Generator, Iterator, TypeVar, Generic
 
 from aiocdp.core.interfaces.target import ITarget
 from aiocdp.utils import UNDEFINED
 
+_ProcessT = TypeVar('_ProcessT')
 
-class IChrome(ABC):
+
+class IChrome(ABC, Generic[_ProcessT]):
     """
     Represents an instance of a Chrome Browser
     """
@@ -16,25 +18,31 @@ class IChrome(ABC):
         cls,
         host: str,
         port: int,
-    ):
+    ) -> 'IChrome':
         """
         Initializer method for the Chrome classes
         """
         pass
 
     @abstractmethod
-    def start(self):
+    def start(
+            self,
+            command: str = None,
+            extra_cli_args: list[str] = None
+    ) -> _ProcessT:
         """
-        Starts the chrome instance
+        Starts the chrome instance and returns the process.
         """
         pass
 
+    @abstractmethod
     def close_tab(self, target_id: str):
         """
         Closes the tab with the given target id.
         """
         pass
 
+    @abstractmethod
     def get_first_target(
             self,
             condition: Callable[[ITarget], bool] = None,
@@ -46,19 +54,36 @@ class IChrome(ABC):
         """
         pass
 
+    @abstractmethod
+    def get_host(self) -> str:
+        """
+        Returns the host of the chrome instance
+        """
+        pass
+
+    @abstractmethod
+    def get_port(self) -> int:
+        """
+        Returns the port of the chrome instance
+        """
+        pass
+
+    @abstractmethod
     def get_targets(self) -> list[ITarget]:
         """
         Fetches a list of all the targets.
         """
         pass
 
-    def iterate_targets(self):
+    @abstractmethod
+    def iterate_targets(self) -> Iterator[ITarget]:
         """
         Returns a generator that fetches and iterates over all the targets.
         """
         pass
 
-    def open_tab(self, tab_url: str = None) -> ITarget:
+    @abstractmethod
+    def open_tab(self, url: str = None) -> ITarget:
         """
         Opens a new tab.
         """
