@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Coroutine, Any
 
 from aiocdp.core.interfaces.stream import IEventStream, IEventStreamReader
 
@@ -10,15 +11,14 @@ class IConnection(ABC):
 
     @classmethod
     @abstractmethod
-    def init(cls, ws_url: str):
+    def init(cls, ws_url: str) -> 'IConnection':
         """
         Initializer method for the IConnection class
         """
         pass
 
-    @property
     @abstractmethod
-    def is_connected(self):
+    def is_connected(self) -> bool:
         """
         Returns whether the connection is closed.
         """
@@ -30,19 +30,21 @@ class IConnection(ABC):
         """
         pass
 
-    async def connect(self):
+    def connect(self) -> Coroutine[None, None, Any]:
         """
-        Connects to the websocket and starts the listener task.
+        Connects to the websocket and starts the listener task. Returns a future that resolves when the connection is
+        established.
         """
         pass
 
-    async def disconnect(self):
+    def disconnect(self) -> Coroutine[None, None, Any]:
         """
-        Disconnects from the websocket and cancels the listener task.
+        Disconnects from the websocket and cancels the listener task. Returns a future that resolves when the
+        connection is closed.
         """
         pass
 
-    def is_stream_closed(self, stream: 'IEventStream'):
+    def is_stream_closed(self, stream: 'IEventStream') -> bool:
         """
         Checks if the given stream is closed.
         """
@@ -54,8 +56,8 @@ class IConnection(ABC):
         """
         pass
 
-    async def send(self, method: str, params: dict):
+    def send(self, method: str, params: dict) -> Coroutine[None, None, Any]:
         """
-        Sends a message to the websocket.
+        Sends a message to the websocket. Returns a future that resolves when the message is sent.
         """
         pass
